( cd usr/lib ; rm -rf libscrollkeeper.so )
( cd usr/lib ; ln -sf libscrollkeeper.so.0.0.0 libscrollkeeper.so )
( cd usr/lib ; rm -rf libscrollkeeper.so.0 )
( cd usr/lib ; ln -sf libscrollkeeper.so.0.0.0 libscrollkeeper.so.0 )
